@@ -339,8 +339,8 @@ if ($PROGRAM_NAME eq "scripts/debrebuild.pl" && -x "scripts/debsnap.pl") {
 if (!-e $dsc_fname) {
     print(  "I: obtaining dsc using: $debsnapexe --force"
           . " --destdir . $srcpkgname $srcpkgver\n");
-    0 == system $debsnapexe, '--force', '--verbose', '--destdir', '.',
-      $srcpkgname, $srcpkgver
+    0 == system $debsnapexe, '--force', '--verbose', '--destdir',
+      dirname($buildinfo), $srcpkgname, $srcpkgver
       or die "$debsnapexe failed\n";
 }
 if (!-e $dsc_fname) {
@@ -677,7 +677,10 @@ if ($builder eq "none") {
     push @cmd, "--bd-uninstallable-explainer=";
 
     if ($custom_build_path) {
-        push @cmd, "--build-path=$custom_build_path";
+        my @dirs       = File::Spec->splitdir($custom_build_path);
+        my $build_path = File::Spec->catdir(@dirs[0 .. $#dirs - 1]);
+        push @cmd, "--build-path=$build_path";
+        push @cmd, "--dsc-dir=$dirs[-1]";
     }
     push @cmd, (File::Spec->rel2abs($dsc_fname));
     print((join " ", @cmd) . "\n");
